@@ -5,6 +5,7 @@ from checkov.circleci_pipelines.base_circleci_pipelines_check import BaseCircleC
 from checkov.common.models.enums import CheckResult
 from checkov.yaml_doc.enums import BlockType
 
+
 class SuspectCurlInScript(BaseCircleCIPipelinesCheck):
     def __init__(self) -> None:
         name = "Suspicious use of curl in run task"
@@ -13,7 +14,7 @@ class SuspectCurlInScript(BaseCircleCIPipelinesCheck):
             name=name,
             id=id,
             block_type=BlockType.ARRAY,
-            supported_entities=['jobs.*.steps[]']
+            supported_entities=('jobs.*.steps[]',)
         )
 
     def scan_conf(self, conf: dict[str, Any]) -> tuple[CheckResult, dict[str, Any]]:
@@ -30,4 +31,5 @@ class SuspectCurlInScript(BaseCircleCIPipelinesCheck):
                     return CheckResult.FAILED, conf
         return CheckResult.PASSED, conf
 
+
 check = SuspectCurlInScript()
