@@ -12,9 +12,4 @@ class IsTrueAttributeSolver(BaseAttributeSolver):
         if attr is None:
             return False
 
-        # if this value contains an underendered variable, then we cannot evaluate the check,
-        # so return True (since we cannot return UNKNOWN)
-        if self._is_variable_dependant(attr, vertex['source_']):
-            return True
-
         return attr is True
