@@ -2,6 +2,7 @@ from __future__ import annotations
 
 from collections import OrderedDict
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 from dockerfile_parse import DockerfileParser
 from dockerfile_parse.constants import COMMENT_INSTRUCTION
@@ -9,15 +10,18 @@ from dockerfile_parse.constants import COMMENT_INSTRUCTION
 from checkov.common.typing import _SkippedCheck
 from checkov.common.util.suppression import collect_suppressions_for_context
 
+if TYPE_CHECKING:
+    from dockerfile_parse.parser import _Instruction  # only in extra_stubs
 
-def parse(filename: str | Path) -> tuple[dict[str, list[dict[str, int | str]]], list[str]]:
+
+def parse(filename: str | Path) -> tuple[dict[str, list[_Instruction]], list[str]]:
     with open(filename) as dockerfile:
         dfp = DockerfileParser(fileobj=dockerfile)
         return dfp_group_by_instructions(dfp)
 
 
-def dfp_group_by_instructions(dfp: DockerfileParser) -> tuple[dict[str, list[dict[str, int | str]]], list[str]]:
-    result: dict[str, list[dict[str, int | str]]] = OrderedDict()
+def dfp_group_by_instructions(dfp: DockerfileParser) -> tuple[dict[str, list[_Instruction]], list[str]]:
+    result: dict[str, list[_Instruction]] = OrderedDict()
     for instruction in dfp.structure:
         instruction_literal = instruction["instruction"]
         if instruction_literal not in result:
@@ -26,7 +30,7 @@ def dfp_group_by_instructions(dfp: DockerfileParser) -> tuple[dict[str, list[dic
     return result, dfp.lines
 
 
-def collect_skipped_checks(parse_result: dict[str, list[dict[str, int | str]]]) -> list[_SkippedCheck]:
+def collect_skipped_checks(parse_result: dict[str, list[_Instruction]]) -> list[_SkippedCheck]:
     skipped_checks = []
 
     if COMMENT_INSTRUCTION in parse_result:
