@@ -47,8 +47,9 @@ class Runner(ImageReferencerMixin["dict[str, dict[str, Any] | list[dict[str, Any
     def included_paths(self) -> Iterable[str]:
         return (".gitlab-ci.yml", ".gitlab-ci.yaml")
 
-    def get_resource(self, file_path: str, key: str, supported_entities: Iterable[str], definitions: dict[str, Any] | None = None) -> str:
-        start_line, end_line = Runner.get_start_and_end_lines(key)
+    def get_resource(self, file_path: str, key: str, supported_entities: Iterable[str],
+                     definitions: dict[str, Any] | None = None) -> str:
+        start_line, end_line = self.get_start_and_end_lines(key)
         file_config = force_dict(self.definitions[file_path])
         if not file_config:
             return key
@@ -101,14 +102,4 @@ class Runner(ImageReferencerMixin["dict[str, dict[str, Any] | list[dict[str, Any
             manager = GitlabCiImageReferencerManager(workflow_config=config, file_path=file)
             images.extend(manager.extract_images_from_workflow())
 
-        return images
-
-    @staticmethod
-    def get_start_and_end_lines(key: str) -> list[int]:
-        check_name = key.split('.')[-1]
-        if "[" not in check_name or "[]" in check_name:
-            return [-1, -1]
-
-        start_end_line_bracket_index = check_name.index('[')
-
-        return [int(x) for x in check_name[start_end_line_bracket_index + 1: len(check_name) - 1].split(':')]
+        return images
\ No newline at end of file
