@@ -1,21 +1,37 @@
+from __future__ import annotations
+
+from typing import Any, TYPE_CHECKING
+
 from checkov.common.checks.base_check_registry import BaseCheckRegistry
 
+if TYPE_CHECKING:
+    from checkov.common.checks.base_check import BaseCheck
+    from checkov.common.typing import _SkippedCheck, _CheckResult
+    from checkov.runner_filter import RunnerFilter
+
 
 class Registry(BaseCheckRegistry):
-    def __init__(self, report_type: str):
+    def __init__(self, report_type: str) -> None:
         super().__init__(report_type)
 
-    def extract_entity_details(self, entity):
+    def extract_entity_details(self, entity: dict[str, Any]) -> tuple[str, dict[str, Any]]:  # type:ignore[override]
         kind = entity.get("kind") or ""
         conf = entity
         return kind, conf
 
-    def scan(self, scanned_file, entity, skipped_checks, runner_filter):
+    def scan(
+        self,
+        scanned_file: str,
+        entity: dict[str, Any],
+        skipped_checks: list[_SkippedCheck],
+        runner_filter: RunnerFilter,
+        report_type: str | None = None,
+    ) -> dict[BaseCheck, _CheckResult]:
         (entity_type, entity_configuration) = self.extract_entity_details(entity)
         results = {}
         checks = self.get_checks(entity_type)
         for check in checks:
-            skip_info = {}
+            skip_info: "_SkippedCheck" = {}
             if skipped_checks:
                 if check.id in [x['id'] for x in skipped_checks]:
                     skip_info = [x for x in skipped_checks if x['id'] == check.id][0]
@@ -29,7 +45,9 @@ class Registry(BaseCheckRegistry):
         return results
 
     @staticmethod
-    def _should_run_scan(check, entity_configuration, runner_filter, report_type):
+    def _should_run_scan(
+        check: BaseCheck, entity_configuration: dict[str, Any], runner_filter: RunnerFilter, report_type: str
+    ) -> bool:
         check_id_allowlist = runner_filter.checks
         check_id_denylist = runner_filter.skip_checks
         if check_id_allowlist or runner_filter.check_threshold:
