@@ -13,12 +13,6 @@ class SeccompPSP(BaseK8Check):
         categories = [CheckCategories.KUBERNETES]
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_kind)
 
-    def get_resource_id(self, conf):
-        if "metadata" in conf:
-            if "name" in conf["metadata"]:
-                return 'PodSecurityPolicy.{}'.format(conf["metadata"]["name"])
-        return 'PodSecurityPolicy.annotations.seccomp.security.alpha.kubernetes.io/defaultProfileName'
-
     def scan_spec_conf(self, conf):
         if "metadata" in conf:
             if "annotations" in conf["metadata"] and conf["metadata"].get("annotations"):
