@@ -21,17 +21,19 @@ from detect_secrets.util.filetype import FileType
 from detect_secrets.util.filetype import determine_file_type
 
 from checkov.secrets.runner import SOURCE_CODE_EXTENSION
+from checkov.common.parsers.multiline_parser import BaseMultiLineParser
+from checkov.common.parsers.yaml.multiline_parser import yml_multiline_parser
+from checkov.common.parsers.json.multiline_parser import json_multiline_parser
 
 if TYPE_CHECKING:
     from detect_secrets.core.potential_secret import PotentialSecret
     from detect_secrets.util.code_snippet import CodeSnippet
 
 MAX_LINE_LENGTH = 10000
+MAX_KEYWORD_LIMIT = 500
 ENTROPY_KEYWORD_COMBINATOR_LIMIT = 3
 ENTROPY_KEYWORD_LIMIT = 4.5
 
-INDENTATION_PATTERN = re.compile(r'(^\s*(?:-?\s+)?)')
-COMMENT_PREFIX = re.compile(r'^[\s]*(#|\/\/)')
 
 DENY_LIST_REGEX = r'|'.join(DENYLIST)
 # Support for suffix after keyword i.e. password_secure = "value"
@@ -58,6 +60,18 @@ FOLLOWED_BY_COLON_VALUE_KEYWORD_REGEX = re.compile(
     flags=re.IGNORECASE,
 )
 
+QUOTES_REQUIRED_FOLLOWED_BY_COLON_VALUE_KEYWORD_REGEX = re.compile(
+    # e.g. var: MY_PASSWORD_123
+    r'{whitespace}"({key})?":{whitespace}("?){words}{denylist}({closing})?(\3)'.format(
+        key=KEY,
+        whitespace=OPTIONAL_WHITESPACE,
+        words=AFFIX_REGEX,
+        denylist=DENY_LIST_REGEX2,
+        closing=CLOSING,
+    ),
+    flags=re.IGNORECASE,
+)
+
 FOLLOWED_BY_COLON_VALUE_SECRET_REGEX = re.compile(
     # e.g. var: Zmlyc3Rfc2VjcmV0X2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzE==
     r'{whitespace}({key})?:{whitespace}({quote}?)({secret})(\3)'.format(
@@ -69,20 +83,48 @@ FOLLOWED_BY_COLON_VALUE_SECRET_REGEX = re.compile(
     flags=re.IGNORECASE,
 )
 
-PAIR_VALUE_KEYWORD_REGEX_TO_GROUP = {
+QUOTES_REQUIRED_FOLLOWED_BY_COLON_VALUE_SECRET_REGEX = re.compile(
+    # e.g. var: Zmlyc3Rfc2VjcmV0X2hlcmVfd2hvYV9tdWx0aWxsaW5lX3Nob3VsZF93b3JrXzE==
+    r'{whitespace}"({key})?":{whitespace}("?)({secret})(\3)'.format(
+        key=KEY,
+        whitespace=OPTIONAL_WHITESPACE,
+        secret=SECRET,
+    ),
+    flags=re.IGNORECASE,
+)
+
+#  if the current regex is not enough, can add more regexes to check
+
+YML_PAIR_VALUE_KEYWORD_REGEX_TO_GROUP = {
     FOLLOWED_BY_COLON_VALUE_KEYWORD_REGEX: 4,
 }
 
-PAIR_VALUE_SECRET_REGEX_TO_GROUP = {
+YML_PAIR_VALUE_SECRET_REGEX_TO_GROUP = {
     FOLLOWED_BY_COLON_VALUE_SECRET_REGEX: 4,
 }
 
+JSON_PAIR_VALUE_KEYWORD_REGEX_TO_GROUP = {
+    QUOTES_REQUIRED_FOLLOWED_BY_COLON_VALUE_KEYWORD_REGEX: 4,
+}
+
+JSON_PAIR_VALUE_SECRET_REGEX_TO_GROUP = {
+    QUOTES_REQUIRED_FOLLOWED_BY_COLON_VALUE_SECRET_REGEX: 4,
+}
+
+
 REGEX_VALUE_KEYWORD_BY_FILETYPE = {
-    FileType.YAML: PAIR_VALUE_KEYWORD_REGEX_TO_GROUP,
+    FileType.YAML: YML_PAIR_VALUE_KEYWORD_REGEX_TO_GROUP,
+    FileType.JSON: JSON_PAIR_VALUE_KEYWORD_REGEX_TO_GROUP,
 }
 
 REGEX_VALUE_SECRET_BY_FILETYPE = {
-    FileType.YAML: PAIR_VALUE_SECRET_REGEX_TO_GROUP,
+    FileType.YAML: YML_PAIR_VALUE_SECRET_REGEX_TO_GROUP,
+    FileType.JSON: JSON_PAIR_VALUE_SECRET_REGEX_TO_GROUP,
+}
+
+MULTILINE_PARSERS = {
+    FileType.YAML: yml_multiline_parser,
+    FileType.JSON: json_multiline_parser,
 }
 
 
@@ -96,7 +138,7 @@ class EntropyKeywordCombinator(BasePlugin):
         self.keyword_scanner = KeywordDetector()
 
     def analyze_string(self, string: str) -> Generator[str, None, None]:
-        pass
+        yield ""
 
     def analyze_line(
             self,
@@ -109,8 +151,7 @@ class EntropyKeywordCombinator(BasePlugin):
     ) -> set[PotentialSecret]:
         is_iac = f".{filename.split('.')[-1]}" not in SOURCE_CODE_EXTENSION
         filetype = determine_file_type(filename)
-        value_keyword_regex_to_group = REGEX_VALUE_KEYWORD_BY_FILETYPE.get(filetype, None)
-        secret_keyword_regex_to_group = REGEX_VALUE_SECRET_BY_FILETYPE.get(filetype, None)
+        multiline_parser = MULTILINE_PARSERS.get(filetype)
 
         if len(line) <= MAX_LINE_LENGTH:
             if is_iac:
@@ -127,10 +168,13 @@ class EntropyKeywordCombinator(BasePlugin):
 
                 # not so classic key-value pair, from multiline, that is only in an array format.
                 # The scan is one-way backwards, so no duplicates expected.
-                elif filetype == FileType.YAML:
-                    return self.analyze_iac_line_yml(
+                elif multiline_parser:
+                    value_keyword_regex_to_group = REGEX_VALUE_KEYWORD_BY_FILETYPE.get(filetype)
+                    secret_keyword_regex_to_group = REGEX_VALUE_SECRET_BY_FILETYPE.get(filetype)
+                    return self.analyze_multiline(
                         filename=filename,
                         line=line,
+                        multiline_parser=multiline_parser,
                         line_number=line_number,
                         context=context,
                         raw_context=raw_context,
@@ -148,10 +192,11 @@ class EntropyKeywordCombinator(BasePlugin):
                 )
         return set()
 
-    def analyze_iac_line_yml(
+    def analyze_multiline(
             self,
             filename: str,
             line: str,
+            multiline_parser: BaseMultiLineParser,
             line_number: int = 0,
             context: CodeSnippet | None = None,
             raw_context: CodeSnippet | None = None,
@@ -159,10 +204,13 @@ class EntropyKeywordCombinator(BasePlugin):
             secret_pattern: dict[Pattern[str], int] | None = None,
             **kwargs: Any,
     ) -> set[PotentialSecret]:
-        secrets = set()
-        if context is not None and raw_context is not None:
-            value_secret = self.extract_from_string(pattern=secret_pattern, string=context.target_line)
-            secret_adjust = self.format_reducing_noise_secret(value_secret)
+        secrets: set[PotentialSecret] = set()
+        if context is None or raw_context is None:
+            return secrets
+        value_secrets = self.extract_from_string(pattern=secret_pattern, string=context.target_line)
+        for possible_secret in value_secrets:
+            secret_adjust = self.format_reducing_noise_secret(possible_secret)
+
             entropy_on_value = self.detect_secret(
                 scanners=self.high_entropy_scanners,
                 filename=filename,
@@ -173,10 +221,19 @@ class EntropyKeywordCombinator(BasePlugin):
 
             if entropy_on_value:
                 possible_keywords: set[str] = set()
-                forward_range = range(context.target_index - 1, -1, -1)
-                backwards_range = range(context.target_index + 1, len(context.lines))
-                possible_keywords |= self.get_lines_from_same_object(forward_range, context, raw_context)
-                possible_keywords |= self.get_lines_from_same_object(backwards_range, context, raw_context)
+                backwards_range = range(context.target_index - 1, -1, -1)
+                forward_range = range(context.target_index + 1, len(context.lines))
+
+                possible_keywords |= multiline_parser.get_lines_from_same_object(
+                    search_range=forward_range,
+                    context=context,
+                    raw_context=raw_context,
+                    line_length_limit=MAX_KEYWORD_LIMIT)
+                possible_keywords |= multiline_parser.get_lines_from_same_object(
+                    search_range=backwards_range,
+                    context=context,
+                    raw_context=raw_context,
+                    line_length_limit=MAX_KEYWORD_LIMIT)
 
                 for other_value in possible_keywords:
                     if self.extract_from_string(pattern=value_pattern, string=other_value):
@@ -184,79 +241,20 @@ class EntropyKeywordCombinator(BasePlugin):
                         break
         return secrets
 
-    def get_lines_from_same_object(
-            self,
-            search_range: range,
-            context: CodeSnippet | None,
-            raw_context: CodeSnippet | None
-    ) -> set[str]:
-        possible_keywords: set[str] = set()
-        if not context or not raw_context:
-            return possible_keywords
-        for j in search_range:
-            line = context.lines[j]
-            if self.lines_in_same_object(raw_context=raw_context, idx=j) \
-                    and not self.line_is_comment(line):
-                possible_keywords.add(raw_context.lines[j])
-                if self.is_object_start(raw_context=raw_context, idx=j):
-                    return possible_keywords
-        return possible_keywords
-
     @staticmethod
     def format_reducing_noise_secret(string: str) -> str:
         return json.dumps(string)
 
-    def lines_in_same_object(
-            self,
-            raw_context: CodeSnippet | None,
-            idx: int
-    ) -> bool:
-        if not raw_context:
-            return False  # could not know
-        return 0 <= idx < len(raw_context.lines) and 0 <= idx + 1 < len(raw_context.lines)\
-            and self.lines_same_indentation(raw_context.lines[idx], raw_context.lines[idx + 1])
-
     @staticmethod
-    def is_object_start(
-            raw_context: CodeSnippet | None,
-            idx: int
-    ) -> bool:
-        if not raw_context:
-            return False  # could not know
-        match = re.match(INDENTATION_PATTERN, raw_context.lines[idx])
-        if match:
-            return '-' in match.groups()[0]
-        return False
-
-    @staticmethod
-    def line_is_comment(line: str) -> bool:
-        if re.match(COMMENT_PREFIX, line):
-            return True
-        return False
-
-    @staticmethod
-    def extract_from_string(pattern: dict[Pattern[str], int] | None, string: str) -> str:
+    def extract_from_string(pattern: dict[Pattern[str], int] | None, string: str) -> set[str]:
+        matches: set[str] = set()
         if not pattern:
-            return ''
+            return matches
         for value_regex, group_number in pattern.items():
             match = value_regex.search(string)
             if match:
-                return match.group(group_number)
-        return ''
-
-    @staticmethod
-    def lines_same_indentation(line1: str, line2: str) -> bool:
-        match1 = re.match(INDENTATION_PATTERN, line1)
-        match2 = re.match(INDENTATION_PATTERN, line2)
-        if not match1 and not match2:
-            return True
-        if not match1 or not match2:
-            return False
-        indent1 = len(match1.groups()[0])
-        indent2 = len(match2.groups()[0])
-        if indent1 == indent2:
-            return True
-        return False
+                matches |= {match.group(group_number)}
+        return matches
 
     @staticmethod
     def detect_secret(
