@@ -386,7 +386,7 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
             changed_attributes = filter_sub_keys(changed_attributes)
             self.update_vertex_config(vertex, changed_attributes)
 
-    def update_vertex_config(self, vertex: TerraformBlock, changed_attributes: Union[List[str], Dict[str, Any]]) -> None:
+    def update_vertex_config(self, vertex: TerraformBlock, changed_attributes: Union[List[str], Dict[str, Any]], dynamic_blocks: bool = False) -> None:
         if not changed_attributes:
             # skip, if there is no change
             return
@@ -407,12 +407,12 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
             if new_value is not None:
                 if vertex.block_type == BlockType.LOCALS:
                     changed_attribute = changed_attribute.replace(vertex.name + ".", "")
-                updated_config = update_dictionary_attribute(updated_config, changed_attribute, new_value)
+                updated_config = update_dictionary_attribute(updated_config, changed_attribute, new_value, dynamic_blocks)
 
         if len(changed_attributes) > 0:
             if vertex.block_type == BlockType.LOCALS:
                 updated_config = updated_config.get(vertex.name)
-            update_dictionary_attribute(vertex.config, vertex.name, updated_config)
+            update_dictionary_attribute(vertex.config, vertex.name, updated_config, dynamic_blocks)
 
     def get_resources_types_in_graph(self) -> List[str]:
         return self.module.get_resources_types()
@@ -471,8 +471,19 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
         return dir_name
 
 
+def to_list(data):
+    if isinstance(data, list) and len(data) == 1 and (isinstance(data[0], str) or isinstance(data[0], int)):
+        return data
+    elif isinstance(data, list):
+        return [to_list(x) for x in data]
+    elif isinstance(data, dict):
+        return {key: to_list(val) for key, val in data.items()}
+    else:
+        return [data]
+
+
 def update_dictionary_attribute(
-        config: Union[List[Any], Dict[str, Any]], key_to_update: str, new_value: Any
+        config: Union[List[Any], Dict[str, Any]], key_to_update: str, new_value: Any, dynamic_blocks: bool = False
 ) -> Union[List[Any], Dict[str, Any]]:
     key_parts = key_to_update.split(".")
 
@@ -484,25 +495,26 @@ def update_dictionary_attribute(
             if len(key_parts) == 1:
                 if isinstance(inner_config, list) and not isinstance(new_value, list):
                     new_value = [new_value]
-                config[key] = new_value
+                config[key] = to_list(new_value) if dynamic_blocks else new_value
                 return config
             else:
-                config[key] = update_dictionary_attribute(inner_config, ".".join(key_parts[1:]), new_value)
+                config[key] = update_dictionary_attribute(inner_config, ".".join(key_parts[1:]), new_value, dynamic_blocks=dynamic_blocks)
         else:
             for key in config:
-                config[key] = update_dictionary_attribute(config[key], key_to_update, new_value)
+                config[key] = update_dictionary_attribute(config[key], key_to_update, new_value, dynamic_blocks=dynamic_blocks)
     if isinstance(config, list):
         return update_list_attribute(
             config=config,
             key_parts=key_parts,
             key_to_update=key_to_update,
             new_value=new_value,
+            dynamic_blocks=dynamic_blocks
         )
     return config
 
 
 def update_list_attribute(
-    config: list[Any], key_parts: list[str], key_to_update: str, new_value: Any
+    config: list[Any], key_parts: list[str], key_to_update: str, new_value: Any, dynamic_blocks: bool = False
 ) -> list[Any] | dict[str, Any]:
     """Updates a list attribute in the given config"""
 
@@ -523,6 +535,6 @@ def update_list_attribute(
             return config
 
     for i, config_value in enumerate(config):
-        config[i] = update_dictionary_attribute(config=config_value, key_to_update=key_to_update, new_value=new_value)
+        config[i] = update_dictionary_attribute(config=config_value, key_to_update=key_to_update, new_value=new_value, dynamic_blocks=dynamic_blocks)
 
     return config
