@@ -4,6 +4,7 @@ from abc import ABC, abstractmethod
 from typing import Optional
 
 from checkov.terraform.module_loading.content import ModuleContent
+from checkov.terraform.module_loading.module_params import ModuleParams
 from checkov.terraform.module_loading.registry import module_loader_registry
 
 
@@ -26,22 +27,13 @@ class ModuleLoader(ABC):
         self.root_dir = ""  # root dir for storing external modules
 
     @abstractmethod
-    def discover(self):
+    def discover(self, module_params: ModuleParams):
         """
             discover parameters from execution context of checkov. usually from env variable
         """
         pass
 
-    def load(
-        self,
-        root_dir: str,
-        current_dir: str,
-        source: str,
-        source_version: Optional[str],
-        dest_dir: str,
-        external_modules_folder_name: str,
-        inner_module: Optional[str] = None,
-    ) -> ModuleContent:
+    def load(self, module_params: ModuleParams) -> ModuleContent:
         """
 This function provides an opportunity for the loader to load a module's content if it chooses to do so.
 There are three resulting states that can occur when calling this function:
@@ -52,43 +44,31 @@ There are three resulting states that can occur when calling this function:
     the module files
  3) the loader tried to load the module content but and error occurred, in which case an exception
     is raised.
-        :param current_dir: Directory containing the reference to the module.
-        :param source: the raw source string from the module's `source` attribute (e.g.,
-                       "hashicorp/consul/aws" or "git::https://example.com/vpc.git?ref=v1.2.0")
-        :param source_version: contains content from the module's `version` attribute, if provided
-        :param dest_dir: where to save the downloaded module
+        :param module_params: dataclass object that contains all the parameters of the module to load.
+                              the data of this object can be changed according to the loader logic
         :return: A ModuleContent object which may or may not being loaded.
         """
-        self.root_dir = root_dir
-
-        self.module_source = source
-        self.current_dir = current_dir
-        self.version = str(source_version)
-
-        self.dest_dir = dest_dir
-        self.external_modules_folder_name = external_modules_folder_name
-        self.inner_module = inner_module
-
-        if not self._is_matching_loader():
+        self.discover(module_params)
+        if not self._is_matching_loader(module_params):
             return ModuleContent(dir=None)
 
-        module_path = self._find_module_path()
+        module_path = self._find_module_path(module_params)
         if os.path.exists(module_path):
             return ModuleContent(dir=module_path)
 
         self.logger.debug(f"Using {self.__class__.__name__} attempting to get module "
-                          f"{self.module_source if '@' not in self.module_source else self.module_source.split('@')[1]} "
-                          f"version: {self.version}")
-        return self._load_module()
+                          f"{module_params.module_source if '@' not in module_params.module_source else module_params.module_source.split('@')[1]} "
+                          f"version: {module_params.version}")
+        return self._load_module(module_params)
 
     @abstractmethod
-    def _is_matching_loader(self) -> bool:
+    def _is_matching_loader(self, module_params: ModuleParams) -> bool:
         raise NotImplementedError()
 
     @abstractmethod
-    def _load_module(self) -> ModuleContent:
+    def _load_module(self, module_params: ModuleParams) -> ModuleContent:
         raise NotImplementedError()
 
     @abstractmethod
-    def _find_module_path(self) -> str:
+    def _find_module_path(self, module_params: ModuleParams) -> str:
         raise NotImplementedError()
